@@ -4,7 +4,8 @@ import json
 
 user_id = os.environ['USER_ID']
 token = os.environ['API_TOKEN']
-url_api = os.environ['VERIFY_ENDPOINT']
+url_api = os.environ['API_ROOT']
+url_endpoint = url_api + "/user/project/task/verify"
 headers = {'x-api-key': f"{token}"}
 
 def get_errors_fails(report_path: str):
